@@ -22,13 +22,17 @@ class SpatRasterStack {
 	public:
 		virtual ~SpatRasterStack(){}
 		SpatRasterStack deepCopy();
+
 		SpatMessages msg;
-		void setError(std::string s);
-		void addWarning(std::string s);
-		bool has_error();
-		bool has_warning();
-		std::vector<std::string> getWarnings();
-		std::string getError();
+		void setError(std::string s) { msg.setError(s); }
+		void addWarning(std::string s) { msg.addWarning(s); }
+		void setMessage(std::string s) { msg.setMessage(s); }
+		bool hasError() { return msg.has_error; }
+		bool hasWarning() { return msg.has_warning; }
+		std::vector<std::string> getWarnings() { return msg.getWarnings();}
+		std::string getError() { return msg.getError();}
+		std::string getMessage() { return msg.getMessage();}
+
 
 		std::vector<SpatRaster> ds;
 		std::vector<std::string> names;
@@ -95,14 +99,17 @@ class SpatRasterStack {
 class SpatRasterCollection {
 	public:
 		virtual ~SpatRasterCollection(){}	
-		SpatMessages msg;
 		SpatRasterCollection deepCopy();
-		void setError(std::string s);
-		void addWarning(std::string s);
-		bool has_error();
-		bool has_warning();
-		std::vector<std::string> getWarnings();
-		std::string getError();
+
+		SpatMessages msg;
+		void setError(std::string s) { msg.setError(s); }
+		void addWarning(std::string s) { msg.addWarning(s); }
+		void setMessage(std::string s) { msg.setMessage(s); }
+		bool hasError() { return msg.has_error; }
+		bool hasWarning() { return msg.has_warning; }
+		std::vector<std::string> getWarnings() { return msg.getWarnings();}
+		std::string getError() { return msg.getError();}
+		std::string getMessage() { return msg.getMessage();}
 	
 		std::vector<SpatRaster> ds;
 //		SpatExtent extent;
@@ -118,11 +125,15 @@ class SpatRasterCollection {
 		void resize(size_t n);
 		void push_back(SpatRaster r, std::string name);
 		void erase(size_t i); 
+		
+		void readBlock(SpatRaster &r, std::vector<std::vector<double>> &v, BlockSize bs, size_t i, std::vector<unsigned> use, SpatOptions opt);
+		std::string make_vrt(std::vector<std::string> options, bool reverse, SpatOptions &opt);
+		
 		SpatRasterCollection crop(SpatExtent e, std::string snap, bool expand, std::vector<unsigned> use, SpatOptions &opt);
 		SpatRasterCollection cropmask(SpatVector v, std::string snap, bool touches, bool expand, std::vector<unsigned> use, SpatOptions &opt);
 		std::vector<int> getValueType(bool unique);
 
-		SpatRaster merge(bool first, bool narm, SpatOptions &opt);
+		SpatRaster merge(bool first, bool narm, int algo, std::string method, SpatOptions &opt);
 		SpatRaster morph(SpatRaster &x, SpatOptions &opt);
 		SpatRaster mosaic(std::string fun, SpatOptions &opt);
 		SpatRaster summary(std::string fun, SpatOptions &opt);
@@ -131,8 +142,13 @@ class SpatRasterCollection {
 		void set_names(std::vector<std::string> nms);
 		std::vector<std::string> filenames();
 		
-
 		SpatRasterStack read_into(SpatRaster &tmp, size_t row, size_t nrows);
 
+		std::map<std::string, std::string> tags;
+		bool addTag(std::string name, std::string value);
+		bool removeTag(std::string name);
+		std::string getTag(std::string name);
+		std::vector<std::string> getTags();
+
 };
 
